@@ -1,3 +1,5 @@
+from typing import Sequence
+
 from libcst import Arg, BaseExpression, Call, Name, SimpleString
 from libcst import matchers as m
 from libcst.codemod.visitors import AddImportsVisitor
@@ -19,6 +21,7 @@ REGEX_TO_CONVERTER = {
     ".+": "path",
     "[-a-zA-Z0-9_]+": "slug",
     r"[\w-]+": "slug",
+    r"[-\w]+": "slug",
     "[^/]+": "str",
     "[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}": "uuid",
 }
@@ -49,7 +52,6 @@ class URLTransformer(BaseFuncRenameTransformer):
         self.check_not_simple_string(first_arg)
         # Extract the URL pattern from the first argument
         pattern = first_arg.value.evaluated_value
-        self.check_missing_start(pattern)
         # If we reach this point, we might be able to use `path()`
         call = self.build_path_call(pattern, other_args)
         AddImportsVisitor.add_needed_import(
@@ -64,11 +66,6 @@ class URLTransformer(BaseFuncRenameTransformer):
         if not m.matches(first_arg, m.Arg(value=m.SimpleString())):
             raise PatternNotSupported()
 
-    def check_missing_start(self, pattern):
-        """Patterns that do not match the start of the string with caret."""
-        if not pattern.startswith("^"):
-            raise PatternNotSupported()
-
     def build_path_call(self, pattern, other_args):
         """Build the `Call` node using Django 2.0's `path()` function."""
         route = self.build_route(pattern)
@@ -102,3 +99,11 @@ class URLTransformer(BaseFuncRenameTransformer):
         """Check that route doesn't contain anymore regex."""
         if set(route) & REGEX_SPECIALS_SANS_DASH:
             raise PatternNotSupported(f"Route {route} contains regex")
+
+    def update_call_args(self, node: Call) -> Sequence[Arg]:
+        """Remove keyword argument from first argument of `re_path`."""
+        first_arg, *other_args = node.args
+        if m.matches(first_arg, m.Arg(keyword=m.Name("regex"))):
+            first_arg = Arg(value=first_arg.value)
+            return (first_arg, *other_args)
+        return super().update_call_args(node)
